/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/*
 *  GThumb
 *
 *  Copyright (C) 2001 The Free Software Foundation, Inc.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
 */

#ifndef POPUP_CALLBACKS_H
#define POPUP_CALLBACKS_H


#include <glib.h>
#include <gtk/gtkwidget.h>


void    view_fullscreen_cb       (GtkWidget *widget,
                                  void *data);

void    add_to_catalog_cb        (GtkWidget *widget,
				  void *data);

void    move_to_catalog_dir_cb   (GtkWidget *widget,
				  void *data);

void    remove_from_catalog_cb   (GtkWidget *widget,
				  void *data);

void    go_to_container_cb       (GtkWidget *widget, 
				  void *data);

void    rename_catalog_cb        (GtkWidget *widget,
				  void *data);

void    delete_catalog_cb        (GtkWidget *widget,
				  void *data);


#endif /* POPUP_CALLBACKS_H */
